from .track_id_enum import TrackIdEnum
from .mtrs_label_enum import MTRSLabelEnum
from .moderation_label_enum import ModerationLabelEnum

from .diagnostics_xml_tag_enum import DiagnosticsXMLTagEnum
from .mtrs_xml_tag_enum import MTRSXMLTagEnum
from .doctor_choice_xml_tag_enum import DoctorChoiceXMLTagEnum

StateEnum, ActionEnum = str, str
